==> ejc-gdjgtask-impl-3.0.0-20211011.040445-14-sources.jar: com/ejianc/business/bean/TaskEntity.java <==
package com.ejianc.business.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 任务
 *
 * @author generator
 *
 */
@TableName("ejc_task")
public class TaskEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="code")
    private java.lang.String code; // 任务编码
    @TableField(value="taks_title")
    private java.lang.String taksTitle; // 任务标题
    @TableField(value="year")
    private java.lang.String year; //
    @TableField(value="promoter_id")
    private java.lang.Long promoterId; // 发起人
    @TableField(value="promoter_name")
    private java.lang.String promoterName; // 发起人名称
    @TableField(value="work_item")
    private java.lang.Integer workItem; // 工作项
    @TableField(value="work_item_status")
    private java.lang.Integer workItemStatus; // 已完成项
    @TableField(value="work_overdue")
    private java.lang.Integer workOverdue; // 逾期项
    @TableField(value="initiate_time")
    private java.util.Date initiateTime; // 发起时间
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="close_item")
    private java.lang.Integer closeItem; //关闭项

    @TableField(exist=false)
    @SubEntity(serviceName = "workService")
    private List<WorkEntity> workItemList = new ArrayList<>();

    /**
     * 任务编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 任务编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 任务标题
     */
    public java.lang.String getTaksTitle() {
        return taksTitle;
    }

    /**
     * 任务标题
     */
    public void setTaksTitle(java.lang.String taksTitle) {
        this.taksTitle = taksTitle;
    }
    /**
     *
     */
    public java.lang.String getYear() {
        return year;
    }

    /**
     *
     */
    public void setYear(java.lang.String year) {
        this.year = year;
    }
    /**
     * 发起人
     */
    public java.lang.Long getPromoterId() {
        return promoterId;
    }

    /**
     * 发起人
     */
    public void setPromoterId(java.lang.Long promoterId) {
        this.promoterId = promoterId;
    }
    /**
     * 发起人名称
     */
    public java.lang.String getPromoterName() {
        return promoterName;
    }

    /**
     * 发起人名称
     */
    public void setPromoterName(java.lang.String promoterName) {
        this.promoterName = promoterName;
    }
    /**
     * 工作项
     */
    public java.lang.Integer getWorkItem() {
        return workItem;
    }

    /**
     * 工作项
     */
    public void setWorkItem(java.lang.Integer workItem) {
        this.workItem = workItem;
    }
    /**
     * 已完成项
     */
    public Integer getWorkItemStatus() {
        return workItemStatus;
    }

    public void setWorkItemStatus(Integer workItemStatus) {
        this.workItemStatus = workItemStatus;
    }

    /**
     * 逾期项
     */
    public java.lang.Integer getWorkOverdue() {
        return workOverdue;
    }

    /**
     * 逾期项
     */
    public void setWorkOverdue(java.lang.Integer workOverdue) {
        this.workOverdue = workOverdue;
    }
    /**
     * 发起时间
     */
    public java.util.Date getInitiateTime() {
        return initiateTime;
    }

    /**
     * 发起时间
     */
    public void setInitiateTime(java.util.Date initiateTime) {
        this.initiateTime = initiateTime;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }

    public List<WorkEntity> getWorkItemList() {
        return workItemList;
    }

    public void setWorkItemList(List<WorkEntity> workItemList) {
        this.workItemList = workItemList;
    }

    public Integer getCloseItem() {
        return closeItem;
    }

    public void setCloseItem(Integer closeItem) {
        this.closeItem = closeItem;
    }
}

==> ejc-gdjgtask-impl-3.0.0-20220901.102341-72-sources.jar: com/ejianc/business/bean/TaskEntity.java <==
package com.ejianc.business.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 任务
 *
 * @author generator
 *
 */
@TableName("ejc_task")
public class TaskEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="code")
    private java.lang.String code; // 任务编码
    @TableField(value="taks_title")
    private java.lang.String taksTitle; // 任务标题
    @TableField(value="year")
    private java.lang.String year; //
    @TableField(value="promoter_id")
    private java.lang.Long promoterId; // 发起人
    @TableField(value="promoter_name")
    private java.lang.String promoterName; // 发起人名称
    @TableField(value="work_item")
    private java.lang.Integer workItem; // 工作项
    @TableField(value="work_item_status")
    private java.lang.Integer workItemStatus; // 已完成项
    @TableField(value="work_overdue")
    private java.lang.Integer workOverdue; // 逾期项
    @TableField(value="initiate_time")
    private java.util.Date initiateTime; // 发起时间
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="close_item")
    private java.lang.Integer closeItem; //关闭项
    /**
     * 变更状态: 0-未变更，1-变更中，2-已变更
     */
    @TableField(value = "change_state")
    private Integer changeState;
    /**
     * 变更中的变更任务Id
     */
    @TableField(value = "cur_changing_task_id")
    private Long curChangingTaskId;
    /**
     * 生效日期
     */
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    @TableField(value = "effective_date")
    private Date effectiveDate;
    /**
     * 变更版本
     */
    @TableField(value = "change_version")
    private Integer changeVersion;

    @TableField(exist=false)
    @SubEntity(serviceName = "workService")
    private List<WorkEntity> workItemList = new ArrayList<>();

    /**
     * 任务编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 任务编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 任务标题
     */
    public java.lang.String getTaksTitle() {
        return taksTitle;
    }

    /**
     * 任务标题
     */
    public void setTaksTitle(java.lang.String taksTitle) {
        this.taksTitle = taksTitle;
    }
    /**
     *
     */
    public java.lang.String getYear() {
        return year;
    }

    /**
     *
     */
    public void setYear(java.lang.String year) {
        this.year = year;
    }
    /**
     * 发起人
     */
    public java.lang.Long getPromoterId() {
        return promoterId;
    }

    /**
     * 发起人
     */
    public void setPromoterId(java.lang.Long promoterId) {
        this.promoterId = promoterId;
    }
    /**
     * 发起人名称
     */
    public java.lang.String getPromoterName() {
        return promoterName;
    }

    /**
     * 发起人名称
     */
    public void setPromoterName(java.lang.String promoterName) {
        this.promoterName = promoterName;
    }
    /**
     * 工作项
     */
    public java.lang.Integer getWorkItem() {
        return workItem;
    }

    /**
     * 工作项
     */
    public void setWorkItem(java.lang.Integer workItem) {
        this.workItem = workItem;
    }
    /**
     * 已完成项
     */
    public Integer getWorkItemStatus() {
        return workItemStatus;
    }

    public void setWorkItemStatus(Integer workItemStatus) {
        this.workItemStatus = workItemStatus;
    }

    /**
     * 逾期项
     */
    public java.lang.Integer getWorkOverdue() {
        return workOverdue;
    }

    /**
     * 逾期项
     */
    public void setWorkOverdue(java.lang.Integer workOverdue) {
        this.workOverdue = workOverdue;
    }
    /**
     * 发起时间
     */
    public java.util.Date getInitiateTime() {
        return initiateTime;
    }

    /**
     * 发起时间
     */
    public void setInitiateTime(java.util.Date initiateTime) {
        this.initiateTime = initiateTime;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }

    public Integer getChangeState() {
        return changeState;
    }

    public void setChangeState(Integer changeState) {
        this.changeState = changeState;
    }

    public Long getCurChangingTaskId() {
        return curChangingTaskId;
    }

    public void setCurChangingTaskId(Long curChangingTaskId) {
        this.curChangingTaskId = curChangingTaskId;
    }

    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }

    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }

    public List<WorkEntity> getWorkItemList() {
        return workItemList;
    }

    public void setWorkItemList(List<WorkEntity> workItemList) {
        this.workItemList = workItemList;
    }

    public Integer getCloseItem() {
        return closeItem;
    }

    public void setCloseItem(Integer closeItem) {
        this.closeItem = closeItem;
    }
}
